#! /usr/bin/env bash

alias @assert=abcli_assert

alias @badge=abcli_badge

alias @browse=abcli_browse

alias @code="abcli_code"

alias @env=abcli_env

alias @eval=abcli_eval

alias @help=abcli_help

alias @hr=abcli_hr

alias @cat=abcli_cat

alias @list=abcli_list

alias @log=abcli_log
alias @error=abcli_log_error
alias @warn=abcli_log_warning

alias @log_list=abcli_log_list

alias @not=abcli_not

alias @open=abcli_open

alias @option=abcli_option
alias @option::int=abcli_option_int
alias @option::choice=abcli_option_choice
alias @option::subset=abcli_option_subset

alias @options=blue_options

alias @pause=abcli_pause

alias @pylint=abcli_pylint
alias @pytest=abcli_pytest

alias @repeat=abcli_repeat

alias @sleep=abcli_sleep

alias @test=abcli_test

alias @timestamp=abcli_string_timestamp
alias @@timestamp=abcli_string_timestamp_short

alias @today=abcli_string_today

alias @watch=abcli_watch
